@@ -47,7 +47,7 @@ class ConnManager:
 
 class Mysql(object):
     def __init__(self, host: str = '127.0.0.1', username: str = 'root', password: str = '123456', db: str = 'test',
-                 drop_column: list = None, pool_num: int = 4, max_pool: int = None, port: int = 3306, monitor=None):
+                 drop_column: list = None, pool_num: int = 4, max_pool: int = None, port: int = 3306, monitor=None,test=False):
         # monitor 历史遗留问题，后续计划删掉
         if drop_column is None:
             drop_column = ["id", "updated", 'created', 'isonline', 'islocal']
@@ -78,9 +78,10 @@ class Mysql(object):
         self.sql_pool.connection()
         self.table_name_list = self.get_db_name()  # 获取所有表名
         self.column_list = {}
+        self.test = test
 
     @staticmethod
-    def simple(config: MysqlConfig, pool_num=4, db: str = None, monitor=None, max_pool: int = None, ) -> 'Mysql':
+    def simple(config: MysqlConfig, pool_num=4, db: str = None, monitor=None, max_pool: int = None, test=False) -> 'Mysql':
         """
         创建Mysql
         :param max_pool: 最大连接数
@@ -101,6 +102,7 @@ class Mysql(object):
             db=db,
             pool_num=pool_num,
             max_pool=max_pool,
+            test=test
         )
         return mysql
 
@@ -190,7 +192,7 @@ class Mysql(object):
             filtered_item = {
                 k: v for k, v in item.items() if
                 k in insert_columns.keys() and not (
-                        v is None and insert_columns[k] in ('bigint', 'int', 'decimal', 'tinyint'))
+                        (v is None or v=='') and insert_columns[k] in ('bigint', 'int', 'decimal', 'tinyint'))
             }
             if not filtered_item:
                 logger.warning(f"没有找到可插入的字段: {item}")
@@ -212,6 +214,10 @@ class Mysql(object):
             try:
                 with ConnManager(self.sql_pool) as cm:
                     cm.cursor.execute(sql, values)
+                    if self.test:
+                        cm.conn.rollback()
+                        logger.warning(f'[TEST MODE] {operation} {table_name} would affect rows: {cm.cursor.rowcount}')
+                        return 0
                     cm.conn.commit()  # 提交事务
                     logger.success(f'{operation} {table_name} rows:{cm.cursor.rowcount} successfully')
                     rowcount = cm.cursor.rowcount
