@@ -9,6 +9,7 @@ import datetime
 from pathlib import Path
 import traceback
 from typing import Optional
+from urllib.parse import urlparse
 
 import requests
 from loguru import logger
@@ -56,10 +57,10 @@ class SpiderInfo:
         self.name = name
         # 分组 以 / 分割 eg: '学术/维普/期刊'
         self.group_name = group_name
-        # 域名
-        self.domain = domain
         # 网址
         self.url = url
+        # 域名
+        self.domain = domain if domain else (urlparse(url).netloc if self.url else self.url)
         # 更新频率
         self.freq = freq
         # 任务类型
@@ -105,7 +106,6 @@ class SpiderInfo:
         self.lan_ip = '127.0.0.1'
         self.wan_ip = os.getenv("WAN_IP", wan_ip)
 
-
         # 是否开启日志输出
         self.__log = log
         # 上报端点
@@ -130,6 +130,7 @@ class SpiderInfo:
         # 注册退出函数
         atexit.register(self.__before_exit)
 
+        self._logeer_id = None
         if self.__log:
             self.__initialize_log_file()
         self.__init_ip()
@@ -156,7 +157,7 @@ class SpiderInfo:
         self.log_file = str(full_path)
 
         if self.log_file:
-            logger.add(self.log_file, rotation="50 MB")
+            self._logeer_id = logger.add(self.log_file, rotation="50 MB")
         self.status = 1
 
     def __global_exception_handler(self, exc_type, exc_value, exc_traceback):
@@ -309,8 +310,9 @@ class SpiderInfo:
 
     def close(self):
         atexit.unregister(self.__before_exit)
-        self.__is_monitor = False
+        sys.excepthook = sys.__excepthook__
         self.__before_exit()
+        self.__is_monitor = False
 
     def __repr__(self):
         return (
